Documentation
¶
Overview ¶
Package tracing provides Datadog tracing utilities for Temporal workflows.
Breaking Changes in v0.5.0 ¶
This release upgrades from dd-trace-go v1 to v2. Most users will not be affected, but there are two breaking changes:
TracerOptions.OnFinish: If you provide a custom OnFinish function, update your import from gopkg.in/DataDog/dd-trace-go.v1/ddtrace/tracer to github.com/DataDog/dd-trace-go/v2/ddtrace/tracer. The tracer.FinishOption type is source-compatible, so no other changes are needed.
SpanFromWorkflowContext: The return type changed from ddtrace.Span to *tracer.Span. If you pass the returned span to code that expects the old type, you will need to update that code.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTracer ¶
func NewTracer(opts TracerOptions) interceptor.Tracer
NewTracer creates an interceptor for setting on client options that implements Datadog tracing for workflows.
func NewTracingInterceptor ¶
func NewTracingInterceptor(opts TracerOptions) interceptor.Interceptor
NewTracingInterceptor convenience method that wraps a NeTracer() with a tracing interceptor
Types ¶
type TracerOptions ¶
type TracerOptions struct {
// DisableSignalTracing can be set to disable signal tracing.
DisableSignalTracing bool
// DisableQueryTracing can be set to disable query tracing.
DisableQueryTracing bool
// DisableUpdateTracing can be set to disable update tracing.
DisableUpdateTracing bool
// OnFinish sets finish options.
// If unset, this will use [tracer.WithError]
// in case [interceptor.TracerFinishSpanOptions.Error] is non-nil and not [workflow.IsContinueAsNewError].
OnFinish func(options *interceptor.TracerFinishSpanOptions) []tracer.FinishOption
}
TracerOptions are options provided to NewInterceptor